//
//  sd_L1stab.c
//
//  SDcard control module mini - Layer 1 Physical block I/O (SDcard SPI protocol) *** DEBUG ***
//  Copyright (C) 2009-2010 Toyohiko Togashi tog001@nifty.com
//
//  This program is free software; you can redistribute it and/or modify it under the terms of the
//  GNU General Public License as published by the Free Software Foundation; either version 3
//  of the License, or (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
//  without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//  See the GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License along with this program.
//  If not, see <http://www.gnu.org/licenses/>
//
//
//	Update history
//	---------- ----- -------------------------------------------
//	2009.12.18 v0.0  First cording
//	2010.01.11 v0.1  Support PIC18F2550
//	2010.01.16 v0.1a Split source
//

#include "sd_config.h"					// Private

#include <fcntl.h>
#include <unistd.h>
#include <stdio.h>


//*********************************************************************
//
//	C o m m o n   a r e a
//
//*********************************************************************

// Data buffer (Share all layer)
#define SD_BUFSZ	512

#ifdef __18CXX
#pragma udata sd_buf					// see linker script
#endif

#ifdef SD_OPT_BUF256
char	sd_buf1[256];					// buf[SD_BUFSZ], ImageCraft compiler limit is 256
char	sd_buf2[256];
#else
char	sd_buf[SD_BUFSZ];
#endif

#ifdef __18CXX
#pragma udata
#endif


//*********************************************************************
//
// Layer 1	Physical block I/O		(512byte/IO, SPI interface)
//
//*********************************************************************


// ------------------
//  DEBUG STUB START
// ------------------
int fd1;
unsigned char sd_L1_open(void){
	unsigned char rc;
	
	rc = 0xff;
	for(;;) {
		if((fd1 = open("dump.img", O_RDWR)) < 0) break;
		rc  = 0;
		break;
	}
	printf("L1open()=%d\n",rc);
	return(rc);
}
void sd_L1_close(void) {
	close(fd1);
	printf("L1close()\n");
	return;
}
void debug_dump(void){
	int i;
	
#ifdef SD_OPT_BUF256
	for(i = 0; i < sizeof(sd_buf1); i++) {
		printf("%02x", (unsigned char)sd_buf1[i]);
		if ((i & 0xf) == 0xf) printf(" ");
		if ((i & 0x1f) == 0x1f) printf("\n");
	}
	for(i = 0; i < sizeof(sd_buf2); i++) {
		printf("%02x", (unsigned char)sd_buf2[i]);
		if ((i & 0xf) == 0xf) printf(" ");
		if ((i & 0x1f) == 0x1f) printf("\n");
	}
#else
	for(i = 0; i < sizeof(sd_buf); i++) {
		printf("%02x", (unsigned char)sd_buf[i]);
		if ((i & 0xf) == 0xf) printf(" ");
		if ((i & 0x1f) == 0x1f) printf("\n");
	}
#endif
}
unsigned char sd_L1_read(long sect){
	unsigned char rc;
	
	rc = 0xff;
	for(;;) {
#ifdef SD_OPT_BUF256
		if (lseek(fd1, sect*512, SEEK_SET) < 0) break;
		if (read(fd1, sd_buf1, sizeof(sd_buf1)) < 0) break;
		if (lseek(fd1, sect*512+sizeof(sd_buf1), SEEK_SET) < 0) break;
		if (read(fd1, sd_buf2, sizeof(sd_buf2)) < 0) break;
#else
		if (lseek(fd1, sect*512, SEEK_SET) < 0) break;
		if (read(fd1, sd_buf, sizeof(sd_buf)) < 0) break;
#endif
		rc  = 0;
		break;
	}
	printf("L1read(sect=%ld)=%d\n",sect,rc);
	debug_dump();
	return(rc);
}
unsigned char sd_L1_write(long sect){
	unsigned char rc;
	
	rc = 0xff;
	for(;;) {
#ifdef SD_OPT_BUF256
		if (lseek(fd1, sect*512, SEEK_SET) < 0) break;
		if (write(fd1, sd_buf1, sizeof(sd_buf1)) < 0) break;
		if (lseek(fd1, sect*512+sizeof(sd_buf1), SEEK_SET) < 0) break;
		if (write(fd1, sd_buf2, sizeof(sd_buf2)) < 0) break;
#else
		if (lseek(fd1, sect*512, SEEK_SET) < 0) break;
		if (write(fd1, sd_buf, sizeof(sd_buf)) < 0) break;
#endif
		rc  = 0;
		break;
	}
	printf("L1write(sect=%ld)=%d\n",sect,rc);
	debug_dump();
	return(rc);
}
// ------------------
//  DEBUG STUB END
// ------------------
